winjob
******************************
Parser for Windows Scheduled Task files

Build Status
============
.. image:: https://img.shields.io/travis/pidydx/winjob.svg
        :target: https://travis-ci.org/pidydx/winjob

.. image:: https://coveralls.io/repos/yahoo/winjob/badge.svg
  :target: https://coveralls.io/r/yahoo/winjob

.. image:: https://pypip.in/download/winjob/badge.svg
    :target: https://pypi.python.org/pypi/winjob/
    
.. image:: https://pypip.in/version/winjob/badge.svg
   :target: https://pypi.python.org/pypi/winjob

.. image:: https://pypip.in/py_versions/winjob/badge.svg
    :target: https://pypi.python.org/pypi/winjob/

.. image:: https://pypip.in/license/winjob/badge.svg
    :target: https://pypi.python.org/pypi/winjob/

.. image:: https://readthedocs.org/projects/winjobbadge/?version=latest
    :target: http://winjob.readthedocs.org/en/latest/
    :alt: Documentation Status
    
More Information
================
* Free software: BSD license, see LICENSE.txt for details
* Documentation: https://winjob.readthedocs.org.

Code licensed under the BSD license. See LICENSE.txt
file for terms.
